Uses of Class
io.netty.handler.codec.ByteToMessageDecoder

Packages that use ByteToMessageDecoder
Package
Description
Extensible decoder and its common implementations which deal with the packet fragmentation and reassembly issue found in a stream-based transport such as TCP/IP.
Encoder and decoder which compresses and decompresses ByteBufs in a compression format such as zlib, gzip, and Snappy.
JSON specific codecs.
Decoder and Encoder which uses JBoss Marshalling.
Encoder and decoder which transform a Google Protocol Buffers Message and MessageNano into a ByteBuf and vice versa.
Encoder, decoder and their compatibility stream implementations which transform a Serializable object into a byte buffer and vice versa.
Xml specific codecs.