Uses of Class
io.netty.handler.codec.MessageToByteEncoder
Packages that use MessageToByteEncoder
Package
Description
Decoder and Encoder which uses JBoss Marshalling.
Encoder and decoder which transform a
Google Protocol Buffers
Message and MessageNano into a
ByteBuf and vice versa.Encoder, decoder and their compatibility stream implementations which
transform a
Serializable object into a byte buffer and
vice versa.-
Uses of MessageToByteEncoder in io.netty.handler.codec.compression
Subclasses of MessageToByteEncoder in io.netty.handler.codec.compressionModifier and TypeClassDescriptionfinal classCompress aByteBufwith the Brotli compression.classCompresses aByteBufusing the Bzip2 algorithm.classCompresses aByteBufusing the FastLZ algorithm.classCompresses aByteBufusing the deflate algorithm.classCompresses aByteBufusing the deflate algorithm.classCompresses aByteBufusing the LZ4 format.classCompresses aByteBufusing the LZF format.classCompresses aByteBufusing the LZMA algorithm.classDeprecated.classCompresses aByteBufusing the Snappy framing format.classCompresses aByteBufusing the deflate algorithm.final classCompresses aByteBufusing the Zstandard algorithm. -
Uses of MessageToByteEncoder in io.netty.handler.codec.marshalling
Subclasses of MessageToByteEncoder in io.netty.handler.codec.marshallingModifier and TypeClassDescriptionclassMessageToByteEncoderimplementation which uses JBoss Marshalling to marshal an Object.classMessageToByteEncoderimplementation which uses JBoss Marshalling to marshal an Object. -
Uses of MessageToByteEncoder in io.netty.handler.codec.protobuf
Subclasses of MessageToByteEncoder in io.netty.handler.codec.protobufModifier and TypeClassDescriptionclassAn encoder that prepends the Google Protocol Buffers Base 128 Varints integer length field. -
Uses of MessageToByteEncoder in io.netty.handler.codec.serialization
Subclasses of MessageToByteEncoder in io.netty.handler.codec.serializationModifier and TypeClassDescriptionclassDeprecated.This class has been deprecated with no replacement, because serialization can be a security liabilityclassDeprecated.This class has been deprecated with no replacement, because serialization can be a security liability
SnappyFrameEncoderinstead.