Class CompatibleObjectEncoder

java.lang.Object
io.netty.channel.ChannelHandlerAdapter
io.netty.channel.ChannelOutboundHandlerAdapter
io.netty.handler.codec.MessageToByteEncoder<Serializable>
io.netty.handler.codec.serialization.CompatibleObjectEncoder
All Implemented Interfaces:
io.netty.channel.ChannelHandler, io.netty.channel.ChannelOutboundHandler

@Deprecated public class CompatibleObjectEncoder extends MessageToByteEncoder<Serializable>
Deprecated.
This class has been deprecated with no replacement, because serialization can be a security liability
An encoder which serializes a Java object into a ByteBuf (interoperability version).

This encoder is interoperable with the standard Java object streams such as ObjectInputStream and ObjectOutputStream.

Security: serialization can be a security liability, and should not be used without defining a list of classes that are allowed to be desirialized. Such a list can be specified with the jdk.serialFilter system property, for instance. See the serialization filtering article for more information.

  • Constructor Details

    • CompatibleObjectEncoder

      public CompatibleObjectEncoder()
      Deprecated.
      Creates a new instance with the reset interval of 16.
    • CompatibleObjectEncoder

      public CompatibleObjectEncoder(int resetInterval)
      Deprecated.
      Creates a new instance.
      Parameters:
      resetInterval - the number of objects between ObjectOutputStream.reset(). 0 will disable resetting the stream, but the remote peer will be at the risk of getting OutOfMemoryError in the long term.
  • Method Details