Class ObjectEncoder

java.lang.Object
io.netty.channel.ChannelHandlerAdapter
io.netty.channel.ChannelOutboundHandlerAdapter
io.netty.handler.codec.MessageToByteEncoder<Serializable>
io.netty.handler.codec.serialization.ObjectEncoder
All Implemented Interfaces:
io.netty.channel.ChannelHandler, io.netty.channel.ChannelOutboundHandler

@Deprecated @Sharable public class ObjectEncoder extends MessageToByteEncoder<Serializable>
Deprecated.
This class has been deprecated with no replacement, because serialization can be a security liability
An encoder which serializes a Java object into a ByteBuf.

Please note that the serialized form this encoder produces is not compatible with the standard ObjectInputStream. Please use ObjectDecoder or ObjectDecoderInputStream to ensure the interoperability with this encoder.

Security: serialization can be a security liability, and should not be used without defining a list of classes that are allowed to be desirialized. Such a list can be specified with the jdk.serialFilter system property, for instance. See the serialization filtering article for more information.

  • Nested Class Summary

    Nested classes/interfaces inherited from interface io.netty.channel.ChannelHandler

    io.netty.channel.ChannelHandler.Sharable
  • Constructor Summary

    Constructors
    Constructor
    Description
    Deprecated.
     
  • Method Summary

    Modifier and Type
    Method
    Description
    protected void
    encode(io.netty.channel.ChannelHandlerContext ctx, Serializable msg, io.netty.buffer.ByteBuf out)
    Deprecated.
    Encode a message into a ByteBuf.

    Methods inherited from class io.netty.handler.codec.MessageToByteEncoder

    acceptOutboundMessage, allocateBuffer, isPreferDirect, write

    Methods inherited from class io.netty.channel.ChannelOutboundHandlerAdapter

    bind, close, connect, deregister, disconnect, flush, read

    Methods inherited from class io.netty.channel.ChannelHandlerAdapter

    ensureNotSharable, exceptionCaught, handlerAdded, handlerRemoved, isSharable

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait

    Methods inherited from interface io.netty.channel.ChannelHandler

    exceptionCaught, handlerAdded, handlerRemoved
  • Constructor Details

    • ObjectEncoder

      public ObjectEncoder()
      Deprecated.
  • Method Details

    • encode

      protected void encode(io.netty.channel.ChannelHandlerContext ctx, Serializable msg, io.netty.buffer.ByteBuf out) throws Exception
      Deprecated.
      Description copied from class: MessageToByteEncoder
      Encode a message into a ByteBuf. This method will be called for each written message that can be handled by this encoder.
      Specified by:
      encode in class MessageToByteEncoder<Serializable>
      Parameters:
      ctx - the ChannelHandlerContext which this MessageToByteEncoder belongs to
      msg - the message to encode
      out - the ByteBuf into which the encoded message will be written
      Throws:
      Exception - is thrown if an error occurs