Package io.netty.handler.codec
Class LineBasedFrameDecoder
java.lang.Object
io.netty.channel.ChannelHandlerAdapter
io.netty.channel.ChannelInboundHandlerAdapter
io.netty.handler.codec.ByteToMessageDecoder
io.netty.handler.codec.LineBasedFrameDecoder
- All Implemented Interfaces:
io.netty.channel.ChannelHandler,io.netty.channel.ChannelInboundHandler
A decoder that splits the received
ByteBufs on line endings.
Both "\n" and "\r\n" are handled.
The byte stream is expected to be in UTF-8 character encoding or ASCII. The current implementation
uses direct byte to char cast and then compares that char to a few low range
ASCII characters like '\n' or '\r'. UTF-8 is not using low range [0..0x7F]
byte values for multibyte codepoint representations therefore fully supported by this implementation.
For a more general delimiter-based decoder, see DelimiterBasedFrameDecoder.
-
Nested Class Summary
Nested classes/interfaces inherited from class io.netty.handler.codec.ByteToMessageDecoder
ByteToMessageDecoder.CumulatorNested classes/interfaces inherited from interface io.netty.channel.ChannelHandler
io.netty.channel.ChannelHandler.Sharable -
Field Summary
Fields inherited from class io.netty.handler.codec.ByteToMessageDecoder
COMPOSITE_CUMULATOR, MERGE_CUMULATOR -
Constructor Summary
ConstructorsConstructorDescriptionLineBasedFrameDecoder(int maxLength) Creates a new decoder.LineBasedFrameDecoder(int maxLength, boolean stripDelimiter, boolean failFast) Creates a new decoder. -
Method Summary
Methods inherited from class io.netty.handler.codec.ByteToMessageDecoder
actualReadableBytes, callDecode, channelInactive, channelRead, channelReadComplete, decodeLast, discardSomeReadBytes, handlerRemoved, handlerRemoved0, internalBuffer, isSingleDecode, setCumulator, setDiscardAfterReads, setSingleDecode, userEventTriggeredMethods inherited from class io.netty.channel.ChannelInboundHandlerAdapter
channelActive, channelRegistered, channelUnregistered, channelWritabilityChanged, exceptionCaughtMethods inherited from class io.netty.channel.ChannelHandlerAdapter
ensureNotSharable, handlerAdded, isSharableMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface io.netty.channel.ChannelHandler
handlerAdded
-
Constructor Details
-
LineBasedFrameDecoder
public LineBasedFrameDecoder(int maxLength) Creates a new decoder.- Parameters:
maxLength- the maximum length of the decoded frame. ATooLongFrameExceptionis thrown if the length of the frame exceeds this value.
-
LineBasedFrameDecoder
public LineBasedFrameDecoder(int maxLength, boolean stripDelimiter, boolean failFast) Creates a new decoder.- Parameters:
maxLength- the maximum length of the decoded frame. ATooLongFrameExceptionis thrown if the length of the frame exceeds this value.stripDelimiter- whether the decoded frame should strip out the delimiter or notfailFast- If true, aTooLongFrameExceptionis thrown as soon as the decoder notices the length of the frame will exceed maxFrameLength regardless of whether the entire frame has been read. If false, aTooLongFrameExceptionis thrown after the entire frame that exceeds maxFrameLength has been read.
-
-
Method Details
-
decode
protected final void decode(io.netty.channel.ChannelHandlerContext ctx, io.netty.buffer.ByteBuf in, List<Object> out) throws Exception Description copied from class:ByteToMessageDecoderDecode the from oneByteBufto an other. This method will be called till either the inputByteBufhas nothing to read when return from this method or till nothing was read from the inputByteBuf.- Specified by:
decodein classByteToMessageDecoder- Parameters:
ctx- theChannelHandlerContextwhich thisByteToMessageDecoderbelongs toin- theByteBuffrom which to read dataout- theListto which decoded messages should be added- Throws:
Exception- is thrown if an error occurs
-
decode
protected Object decode(io.netty.channel.ChannelHandlerContext ctx, io.netty.buffer.ByteBuf buffer) throws Exception Create a frame out of theByteBufand return it.- Parameters:
ctx- theChannelHandlerContextwhich thisByteToMessageDecoderbelongs tobuffer- theByteBuffrom which to read data- Returns:
- frame the
ByteBufwhich represent the frame ornullif no frame could be created. - Throws:
Exception
-