Uses of Class
io.netty.handler.codec.ByteToMessageDecoder
Packages that use ByteToMessageDecoder
Package
Description
Extensible decoder and its common implementations which deal with the
packet fragmentation and reassembly issue found in a stream-based transport
such as TCP/IP.
JSON specific codecs.
Decoder and Encoder which uses JBoss Marshalling.
Encoder and decoder which transform a
Google Protocol Buffers
Message and MessageNano into a
ByteBuf and vice versa.Encoder, decoder and their compatibility stream implementations which
transform a
Serializable object into a byte buffer and
vice versa.Xml specific codecs.
-
Uses of ByteToMessageDecoder in io.netty.handler.codec
Subclasses of ByteToMessageDecoder in io.netty.handler.codecModifier and TypeClassDescriptionclassA decoder that splits the receivedByteBufs by one or more delimiters.classA decoder that splits the receivedByteBufs by the fixed number of bytes.classA decoder that splits the receivedByteBufs dynamically by the value of the length field in the message.classA decoder that splits the receivedByteBufs on line endings.classA specialized variation ofByteToMessageDecoderwhich enables implementation of a non-blocking decoder in the blocking I/O paradigm. -
Uses of ByteToMessageDecoder in io.netty.handler.codec.compression
Subclasses of ByteToMessageDecoder in io.netty.handler.codec.compressionModifier and TypeClassDescriptionfinal classDecompresses aByteBufencoded with the brotli format.classUncompresses aByteBufencoded with the Bzip2 format.classUncompresses aByteBufencoded byFastLzFrameEncoderusing the FastLZ algorithm.classDecompress aByteBufusing the inflate algorithm.classclassUncompresses aByteBufencoded with the LZ4 format.classUncompresses aByteBufencoded with the LZF format.classDeprecated.classUncompresses aByteBufencoded with the Snappy framing format.classDecompresses aByteBufusing the deflate algorithm. -
Uses of ByteToMessageDecoder in io.netty.handler.codec.json
Subclasses of ByteToMessageDecoder in io.netty.handler.codec.jsonModifier and TypeClassDescriptionclassSplits a byte stream of JSON objects and arrays into individual objects/arrays and passes them up theChannelPipeline. -
Uses of ByteToMessageDecoder in io.netty.handler.codec.marshalling
Subclasses of ByteToMessageDecoder in io.netty.handler.codec.marshalling -
Uses of ByteToMessageDecoder in io.netty.handler.codec.protobuf
Subclasses of ByteToMessageDecoder in io.netty.handler.codec.protobufModifier and TypeClassDescriptionclassA decoder that splits the receivedByteBufs dynamically by the value of the Google Protocol Buffers Base 128 Varints integer length field in the message. -
Uses of ByteToMessageDecoder in io.netty.handler.codec.serialization
Subclasses of ByteToMessageDecoder in io.netty.handler.codec.serializationModifier and TypeClassDescriptionclassDeprecated.This class has been deprecated with no replacement, because serialization can be a security liability -
Uses of ByteToMessageDecoder in io.netty.handler.codec.xml
Subclasses of ByteToMessageDecoder in io.netty.handler.codec.xmlModifier and TypeClassDescriptionclassA frame decoder for single separate XML based message streams.
SnappyFrameDecoderinstead.